@@ -82,7 +82,6 @@ class BluexpressHandler:
                 'largo': 10,
                 'ancho': 10,
                 'alto': 10,
-                'quantity': instance.lumps
             }
         ]
 
@@ -126,6 +125,7 @@ class BluexpressHandler:
             'centroCosto': xsd.SkipValue,
             'switchNotificar': 'false',
             'codigoAgencia': '0',
+            'cantidadPiezas': instance.lumps,
             'listaEmisionEmbalajesCrearReq': {
                 'emisionEmbalajeCrearReq': lista_items
             },
